Use as a Python module
======================

The following is the public API of ``imreg_dft``.

See the :ref:`py_examples` section to see how to use it.

imreg module
------------

.. automodule:: imreg_dft.imreg
   :members:
   :undoc-members:


